@@ -118,7 +118,8 @@ enum {
 	PLOTSTYLE_MENU_HISTEPS,
 	PLOTSTYLE_MENU_STEPS,
 	PLOTSTYLE_MENU_CANDLESTICKS,
-	PLOTSTYLE_MENU_DOTS
+	PLOTSTYLE_MENU_DOTS,
+	PLOTSTYLE_MENU_POLAR
 };
 
 enum {
